/*
 * Copyright 2012-2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.autoconfigure.cassandra;

import com.datastax.driver.core.Cluster;

/**
 * Callback interface that can be implemented by beans wishing to customize the
 * {@link Cluster} before it is fully initialized, in particular to tune its
 * configuration.
 *
 * @author Eddú Meléndez
 * @since 1.5.0
 */
public interface ClusterCustomizer {

	/**
	 * Customize the {@link Cluster}.
	 * @param cluster the cluster to customize
	 */
	void customize(Cluster cluster);

}
